summaryrefslogtreecommitdiffstats
path: root/kdvi
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:45:52 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:45:52 -0600
commit6adb71382c3d5277c3dcbc4ec24c5ff36b4c07ef (patch)
tree44659d1cc0c37eb995e572bc1b979e75a74210fb /kdvi
parente2385b701b464dc2259fcd5f3819c98f2c8c4438 (diff)
downloadtdegraphics-6adb71382c3d5277c3dcbc4ec24c5ff36b4c07ef.tar.gz
tdegraphics-6adb71382c3d5277c3dcbc4ec24c5ff36b4c07ef.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kdvi')
-rw-r--r--kdvi/dviFile.cpp2
-rw-r--r--kdvi/dviRenderer.cpp12
-rw-r--r--kdvi/dviRenderer.h8
-rw-r--r--kdvi/dviRenderer_export.cpp32
-rw-r--r--kdvi/dviRenderer_prescan.cpp2
-rw-r--r--kdvi/fontEncoding.cpp2
-rw-r--r--kdvi/fontMap.cpp4
-rw-r--r--kdvi/fontpool.cpp8
-rw-r--r--kdvi/fontpool.h4
-rw-r--r--kdvi/psgs.cpp4
10 files changed, 39 insertions, 39 deletions
diff --git a/kdvi/dviFile.cpp b/kdvi/dviFile.cpp
index 7fb2bef7..1b508367 100644
--- a/kdvi/dviFile.cpp
+++ b/kdvi/dviFile.cpp
@@ -377,7 +377,7 @@ TQString dvifile::convertPDFtoPS(const TQString &PDFFilename)
// Use pdf2ps to do the conversion
KProcIO proc;
proc << "pdf2ps" << PDFFilename << convertedFileName;
- if (proc.start(KProcess::Block) == false)
+ if (proc.start(TDEProcess::Block) == false)
convertedFileName = TQString(); // Indicates that conversion failed, won't try again.
if (!TQFile::exists(convertedFileName))
convertedFileName = TQString(); // Indicates that conversion failed, won't try again.
diff --git a/kdvi/dviRenderer.cpp b/kdvi/dviRenderer.cpp
index 8700c8a2..dfa4c678 100644
--- a/kdvi/dviRenderer.cpp
+++ b/kdvi/dviRenderer.cpp
@@ -767,8 +767,8 @@ void dviRenderer::handleSRCLink(const TQString &linkText, TQMouseEvent *e, Docum
// henceforth dimiss the output of the older programm. "If it
// hasn't failed until now, we don't care."
if (proc != 0) {
- tqApp->disconnect(proc, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)), 0, 0);
- tqApp->disconnect(proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)), 0, 0);
+ tqApp->disconnect(proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), 0, 0);
+ tqApp->disconnect(proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), 0, 0);
proc = 0;
}
@@ -778,9 +778,9 @@ void dviRenderer::handleSRCLink(const TQString &linkText, TQMouseEvent *e, Docum
kdError(4300) << "Could not allocate ShellProcess for the editor command." << endl;
return;
}
- tqApp->connect(proc, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(KProcess *, char *, int)));
- tqApp->connect(proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(KProcess *, char *, int)));
- tqApp->connect(proc, TQT_SIGNAL(processExited(KProcess *)), this, TQT_SLOT(editorCommand_terminated(KProcess *)));
+ tqApp->connect(proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(TDEProcess *, char *, int)));
+ tqApp->connect(proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(TDEProcess *, char *, int)));
+ tqApp->connect(proc, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(editorCommand_terminated(TDEProcess *)));
// Merge the editor-specific editor message here.
export_errorString = i18n("<qt>The external program<br><br><tt><strong>%1</strong></tt><br/><br/>which was used to call the editor "
"for inverse search, reported an error. You might wish to look at the <strong>document info "
@@ -797,7 +797,7 @@ void dviRenderer::handleSRCLink(const TQString &linkText, TQMouseEvent *e, Docum
proc->clearArguments();
*proc << command;
proc->closeStdin();
- if (proc->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false) {
+ if (proc->start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput) == false) {
kdError(4300) << "Editor failed to start" << endl;
return;
}
diff --git a/kdvi/dviRenderer.h b/kdvi/dviRenderer.h
index 355b0530..38d4d897 100644
--- a/kdvi/dviRenderer.h
+++ b/kdvi/dviRenderer.h
@@ -30,7 +30,7 @@ class infoDialog;
class KAction;
class KDVIMultiPage;
class KPrinter;
-class KProcess;
+class TDEProcess;
class KProgressDialog;
class KShellProcess;
class PreBookmark;
@@ -145,9 +145,9 @@ public slots:
virtual void getText(RenderedDocumentPage* page);
/** Slots used in conjunction with external programs */
- void dvips_output_receiver(KProcess *, char *buffer, int buflen);
- void dvips_terminated(KProcess *);
- void editorCommand_terminated(KProcess *);
+ void dvips_output_receiver(TDEProcess *, char *buffer, int buflen);
+ void dvips_terminated(TDEProcess *);
+ void editorCommand_terminated(TDEProcess *);
signals:
/** Passed through to the top-level kpart. */
diff --git a/kdvi/dviRenderer_prescan.cpp b/kdvi/dviRenderer_prescan.cpp
index 81a3b40f..ea923130 100644
--- a/kdvi/dviRenderer_prescan.cpp
+++ b/kdvi/dviRenderer_prescan.cpp
@@ -292,7 +292,7 @@ void dviRenderer::prescan_ParsePSHeaderSpecial(const TQString& cp)
// Otherwise, use kpsewhich to find the eps file.
KProcIO proc;
proc << "kpsewhich" << cp;
- proc.start(KProcess::Block);
+ proc.start(TDEProcess::Block);
proc.readln(_file);
}
diff --git a/kdvi/fontEncoding.cpp b/kdvi/fontEncoding.cpp
index 9f2d4de2..71ed6d9f 100644
--- a/kdvi/fontEncoding.cpp
+++ b/kdvi/fontEncoding.cpp
@@ -28,7 +28,7 @@ fontEncoding::fontEncoding(const TQString &encName)
KProcIO proc;
TQString encFileName;
proc << "kpsewhich" << encName;
- if (proc.start(KProcess::Block) == false) {
+ if (proc.start(TDEProcess::Block) == false) {
kdError(4300) << "fontEncoding::fontEncoding(...): kpsewhich could not be started." << endl;
return;
}
diff --git a/kdvi/fontMap.cpp b/kdvi/fontMap.cpp
index 8ef9b2c7..7b4e35a8 100644
--- a/kdvi/fontMap.cpp
+++ b/kdvi/fontMap.cpp
@@ -33,7 +33,7 @@ fontMap::fontMap()
// teTeX 3.0 format first.
KProcIO proc;
proc << "kpsewhich" << "--format=map" << "ps2pk.map";
- if (proc.start(KProcess::Block) == false) {
+ if (proc.start(TDEProcess::Block) == false) {
kdError(4700) << "fontMap::fontMap(): kpsewhich could not be started." << endl;
return;
}
@@ -45,7 +45,7 @@ fontMap::fontMap()
// Map file not found? Then we try the teTeX < 3.0 way of finding
// the file.
proc << "kpsewhich" << "--format=dvips config" << "ps2pk.map";
- if (proc.start(KProcess::Block) == false) {
+ if (proc.start(TDEProcess::Block) == false) {
kdError(4700) << "fontMap::fontMap(): kpsewhich could not be started." << endl;
return;
}
diff --git a/kdvi/fontpool.cpp b/kdvi/fontpool.cpp
index 463d123b..a9d207eb 100644
--- a/kdvi/fontpool.cpp
+++ b/kdvi/fontpool.cpp
@@ -304,8 +304,8 @@ void fontPool::locateFonts(bool makePK, bool locateTFMonly, bool *virtualFontsFo
// If PK fonts are generated, the kpsewhich command will re-route
// the output of MetaFont into its stderr. Here we make sure this
// output is intercepted and parsed.
- tqApp->connect(&kpsewhichIO, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)),
- this, TQT_SLOT(mf_output_receiver(KProcess *, char *, int)));
+ tqApp->connect(&kpsewhichIO, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
+ this, TQT_SLOT(mf_output_receiver(TDEProcess *, char *, int)));
kpsewhichIO.setUseShell(true);
@@ -357,7 +357,7 @@ void fontPool::locateFonts(bool makePK, bool locateTFMonly, bool *virtualFontsFo
kpsewhichIO << shellProcessCmdLine;
TQString importanceOfKPSEWHICH = i18n("<p>KDVI relies on the <b>kpsewhich</b> program to locate font files "
"on your hard disc and to generate PK fonts, if necessary.</p>");
- if (kpsewhichIO.start(KProcess::NotifyOnExit, false) == false) {
+ if (kpsewhichIO.start(TDEProcess::NotifyOnExit, false) == false) {
TQString msg = i18n( "<p>The shell process for the kpsewhich program could not "
"be started. Consequently, some font files could not be found, "
"and your document might by unreadable. If this error is reproducable "
@@ -544,7 +544,7 @@ void fontPool::release_fonts()
}
-void fontPool::mf_output_receiver(KProcess *, char *buffer, int buflen)
+void fontPool::mf_output_receiver(TDEProcess *, char *buffer, int buflen)
{
// Paranoia.
if (buflen < 0)
diff --git a/kdvi/fontpool.h b/kdvi/fontpool.h
index b3c11846..d5575ff9 100644
--- a/kdvi/fontpool.h
+++ b/kdvi/fontpool.h
@@ -20,7 +20,7 @@
#include FT_FREETYPE_H
#endif
-class KProcess;
+class TDEProcess;
class KShellProcess;
@@ -210,7 +210,7 @@ private slots:
// transmitted to the fontpool via this slot. This method calles
// suitable methods in the fontProgres Dialog, and collects the
// output of MetaFontt int the "MetafontOutput" member
- void mf_output_receiver(KProcess *, char *, int);
+ void mf_output_receiver(TDEProcess *, char *, int);
};
#endif //ifndef _FONTPOOL_H
diff --git a/kdvi/psgs.cpp b/kdvi/psgs.cpp
index d7f087e4..7336d51f 100644
--- a/kdvi/psgs.cpp
+++ b/kdvi/psgs.cpp
@@ -224,7 +224,7 @@ void ghostscript_interface::gs_generate_graphics_file(const PageNumber& page, co
#endif
proc << argus;
- if (proc.start(KProcess::Block) == false) {
+ if (proc.start(TDEProcess::Block) == false) {
// Starting ghostscript did not work.
// TODO: Issue error message, switch PS support off.
kdError(4300) << "ghostview could not be started" << endl;
@@ -331,7 +331,7 @@ TQString ghostscript_interface::locateEPSfile(const TQString &filename, const KU
TQString EPSfilename;
KProcIO proc;
proc << "kpsewhich" << filename;
- proc.start(KProcess::Block);
+ proc.start(TDEProcess::Block);
proc.readln(EPSfilename);
return EPSfilename.stripWhiteSpace();
diff --git a/kdvi/dviRenderer_export.cpp b/kdvi/dviRenderer_export.cpp
index 2b4ffd65..9fd0809e 100644
--- a/kdvi/dviRenderer_export.cpp
+++ b/kdvi/dviRenderer_export.cpp
@@ -61,8 +61,8 @@ void dviRenderer::exportPDF()
// has been called meanwhile. See also the exportPS method.
if (proc != 0) {
// Make sure all further output of the programm is ignored
- tqApp->disconnect(proc, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)), 0, 0);
- tqApp->disconnect(proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)), 0, 0);
+ tqApp->disconnect(proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), 0, 0);
+ tqApp->disconnect(proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), 0, 0);
proc = 0;
}
@@ -130,9 +130,9 @@ void dviRenderer::exportPDF()
}
tqApp->disconnect( this, TQT_SIGNAL(mySignal()), 0, 0 );
- tqApp->connect(proc, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(KProcess *, char *, int)));
- tqApp->connect(proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(KProcess *, char *, int)));
- tqApp->connect(proc, TQT_SIGNAL(processExited(KProcess *)), this, TQT_SLOT(dvips_terminated(KProcess *)));
+ tqApp->connect(proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(TDEProcess *, char *, int)));
+ tqApp->connect(proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(TDEProcess *, char *, int)));
+ tqApp->connect(proc, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(dvips_terminated(TDEProcess *)));
export_errorString = i18n("<qt>The external program 'dvipdf', which was used to export the file, reported an error. "
"You might wish to look at the <strong>document info dialog</strong> which you will "
@@ -145,7 +145,7 @@ void dviRenderer::exportPDF()
*proc << TQString("-o %1").arg(KShellProcess::quote(fileName));
*proc << KShellProcess::quote(dviFile->filename);
proc->closeStdin();
- if (proc->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false) {
+ if (proc->start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput) == false) {
kdError(4300) << "dvipdfm failed to start" << endl;
return;
}
@@ -167,8 +167,8 @@ void dviRenderer::exportPS(const TQString& fname, const TQString& options, KPrin
// enough to ignore the exit status of the editor if another command
// has been called meanwhile. See also the exportPDF method.
if (proc != 0) {
- tqApp->disconnect(proc, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)), 0, 0);
- tqApp->disconnect(proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)), 0, 0);
+ tqApp->disconnect(proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), 0, 0);
+ tqApp->disconnect(proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), 0, 0);
proc = 0;
}
@@ -294,9 +294,9 @@ void dviRenderer::exportPS(const TQString& fname, const TQString& options, KPrin
return;
}
- tqApp->connect(proc, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(KProcess *, char *, int)));
- tqApp->connect(proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(KProcess *, char *, int)));
- tqApp->connect(proc, TQT_SIGNAL(processExited(KProcess *)), this, TQT_SLOT(dvips_terminated(KProcess *)));
+ tqApp->connect(proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(TDEProcess *, char *, int)));
+ tqApp->connect(proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), this, TQT_SLOT(dvips_output_receiver(TDEProcess *, char *, int)));
+ tqApp->connect(proc, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(dvips_terminated(TDEProcess *)));
export_errorString = i18n("<qt>The external program 'dvips', which was used to export the file, reported an error. "
"You might wish to look at the <strong>document info dialog</strong> which you will "
"find in the File-Menu for a precise error report.</qt>") ;
@@ -312,7 +312,7 @@ void dviRenderer::exportPS(const TQString& fname, const TQString& options, KPrin
*proc << TQString("%1").arg(KShellProcess::quote(sourceFileName));
*proc << TQString("-o %1").arg(KShellProcess::quote(fileName));
proc->closeStdin();
- if (proc->start(KProcess::NotifyOnExit, KProcess::Stderr) == false) {
+ if (proc->start(TDEProcess::NotifyOnExit, TDEProcess::Stderr) == false) {
kdError(4300) << "dvips failed to start" << endl;
return;
}
@@ -320,7 +320,7 @@ void dviRenderer::exportPS(const TQString& fname, const TQString& options, KPrin
}
-void dviRenderer::dvips_output_receiver(KProcess *, char *buffer, int buflen)
+void dviRenderer::dvips_output_receiver(TDEProcess *, char *buffer, int buflen)
{
// Paranoia.
if (buflen < 0)
@@ -333,7 +333,7 @@ void dviRenderer::dvips_output_receiver(KProcess *, char *buffer, int buflen)
}
-void dviRenderer::dvips_terminated(KProcess *sproc)
+void dviRenderer::dvips_terminated(TDEProcess *sproc)
{
// Give an error message from the message string. However, if the
// sproc is not the "current external process of interest", i.e. not
@@ -351,7 +351,7 @@ void dviRenderer::dvips_terminated(KProcess *sproc)
}
-void dviRenderer::editorCommand_terminated(KProcess *sproc)
+void dviRenderer::editorCommand_terminated(TDEProcess *sproc)
{
// Give an error message from the message string. However, if the
// sproc is not the "current external process of interest", i.e. not
@@ -372,7 +372,7 @@ void dviRenderer::editorCommand_terminated(KProcess *sproc)
void dviRenderer::abortExternalProgramm()
{
- delete proc; // Deleting the KProcess kills the child.
+ delete proc; // Deleting the TDEProcess kills the child.
proc = 0;
if (export_tmpFileName.isEmpty() != true) {